"""
SKFeatureLLM: LLM-powered feature engineering with scikit-learn compatibility
"""

from skfeaturellm.feature_engineer import LLMFeatureEngineer

__version__ = "0.1.0"
__all__ = ["LLMFeatureEngineer"]
